@@ -110,7 +110,7 @@ namespace PyTango { namespace Pipe {
 					     const char *method)
     {
 	TangoSys_OMemStream o;
-	o << "Wrong Python type for pipe " << name << ends;
+	o << "Wrong Python type for pipe " << name << std::ends;
 	Tango::Except::throw_exception("PyDs_WrongPythonDataTypeForPipe",
 				       o.str(), method);
     }
@@ -469,7 +469,7 @@ namespace PyDevicePipe
 {
 	static void throw_wrong_python_data_type(const std::string &name, const char *method) {
 		TangoSys_OMemStream o;
-		o << "Wrong Python type for pipe " << name << ends;
+		o << "Wrong Python type for pipe " << name << std::ends;
 		Tango::Except::throw_exception("PyDs_WrongPythonDataTypeForPipe",
 				o.str(), method);
 	}
@@ -507,7 +507,7 @@ namespace PyDevicePipe
 	}
 
 	void __append(Tango::DevicePipeBlob& dpb, const std::string& name, bopy::object& value) {
-		if (__check_type<string>(value)) {
+		if (__check_type<std::string>(value)) {
 			__append_scalar<Tango::DevicePipeBlob, Tango::DEV_STRING>(dpb, name, value);
 		} else if (__check_type<int>(value)) {
 			__append_scalar<Tango::DevicePipeBlob, Tango::DEV_LONG64>(dpb, name, value);
@@ -516,7 +516,7 @@ namespace PyDevicePipe
 		} else if (__check_type<bool>(value)) {
 			__append_scalar<Tango::DevicePipeBlob, Tango::DEV_BOOLEAN>(dpb, name, value);
 		} else if (__check_type<bopy::list>(value)) {
-			if (__check_type<string>(value[0])) {
+			if (__check_type<std::string>(value[0])) {
 				__append_array<Tango::DevicePipeBlob, Tango::DEVVAR_STRINGARRAY>(dpb, name, value);
 			} else if (__check_type<int>(value[0])) {
 				__append_array<Tango::DevicePipeBlob, Tango::DEVVAR_LONG64ARRAY>(dpb, name, value);
