@@ -96,6 +96,27 @@ def get_host_ip():
     return ip
 
 
+def _device_class_from_field(field):
+    """
+    Helper function that extracts and return a device class from a
+    'class' field of a devices_info dictionary
+
+    :param field: the field from which to extract the device class
+
+    :return: the device class extracted from the field
+    """
+    device_cls_class = None
+    if is_non_str_seq(field):
+        (device_cls_class, device_class) = (field[0], field[1])
+        if isinstance(device_cls_class, str):
+            device_cls_class = device(device_cls_class)
+    else:
+        device_class = field
+    if isinstance(device_class, str):
+        device_class = device(device_class)
+    return (device_cls_class, device_class)
+
+
 class MultiDeviceTestContext(object):
     """Context to run device(s) without a database.
 
@@ -152,13 +173,21 @@ class MultiDeviceTestContext(object):
     :param devices_info:
       a sequence of dicts with information about
       devices to be exported. Each dict consists of the following keys:
+
         * "class" which value is either of:
-          * :class:`~tango.server.Device`
-          * a sequence of two elements :class:`~tango.DeviceClass`
-            and :class:`~tango.DeviceImpl`
+
+          * :class:`~tango.server.Device` or the name of some such class
+          * a sequence of two elements, the first element being a
+            :class:`~tango.DeviceClass` or the name of some such class,
+            the second element being a :class:`~tango.DeviceImpl` or the
+            name of such such class
+
         * "devices" which value is a sequence of dicts with the following keys:
+
           * "name" (str)
           * "properties" (dict)
+          * "memorized" (dict)
+
     :type devices_info:
       sequence<dict>
     :param server_name:
@@ -171,7 +200,7 @@ class MultiDeviceTestContext(object):
       Optional.  Default is lower-case version of the server name.
     :type instance_name:
       :py:obj:`str`
-    :param db
+    :param db:
       Path to a pre-populated text file to use for the
       database.
       Optional.  Default is to create a new temporary file and populate it
@@ -223,16 +252,15 @@ class MultiDeviceTestContext(object):
                  db=None, host=None, port=0, debug=3,
                  process=False, daemon=False, timeout=None):
         if not server_name:
-            first_cls = devices_info[0]["class"]
-            if is_non_str_seq(first_cls):
-                first_device = first_cls[1]
-            else:
-                first_device = first_cls
+            _, first_device = _device_class_from_field(devices_info[0]["class"])
             server_name = first_device.__name__
         if not instance_name:
             instance_name = server_name.lower()
         if db is None:
-            _, db = tempfile.mkstemp()
+            handle, db = tempfile.mkstemp()
+            self.handle = handle
+        else:
+            self.handle = None
         if host is None:
             # IP address is used instead of the hostname on purpose (see #246)
             host = get_host_ip()
@@ -260,16 +288,10 @@ class MultiDeviceTestContext(object):
         device_list = []
         tangoclass_list = []
         for device_info in devices_info:
-            device_cls = None
-            cls = device_info["class"]
-            if is_non_str_seq(cls):
-                device_cls = cls[0]
-                device = cls[1]
-            else:
-                device = cls
+            device_cls, device = _device_class_from_field(device_info["class"])
             tangoclass = device.__name__
             if tangoclass in tangoclass_list:
-                os.unlink(self.db)
+                self.delete_db()
                 raise ValueError("multiple entries in devices_info pointing "
                                  "to the same Tango class")
             tangoclass_list.append(tangoclass)
@@ -283,7 +305,7 @@ class MultiDeviceTestContext(object):
 
         # Target and arguments
         if class_list and device_list:
-            os.unlink(self.db)
+            self.delete_db()
             raise ValueError("mixing HLAPI and classical API in devices_info "
                              "is not supported")
         if class_list:
@@ -350,8 +372,22 @@ class MultiDeviceTestContext(object):
             patched = dict((key, value if value != '' else ' ')
                            for key, value in properties.items())
             db.put_device_property(device_name, patched)
+
+            memorized = info.get("memorized", {})
+            munged = {
+                attribute_name: {
+                    "__value": memorized_value
+                } for (attribute_name, memorized_value) in memorized.items()
+            }
+            db.put_device_attribute_property(device_name, munged)
         return db
 
+    def delete_db(self):
+        """ delete temporary database file only if it was created by this class """
+        if self.handle is not None:
+            os.close(self.handle)
+            os.unlink(self.db)
+    
     def get_server_access(self):
         """Return the full server name."""
         form = 'tango://{0}:{1}/{2}#{3}'
@@ -411,7 +447,7 @@ class MultiDeviceTestContext(object):
                 self.server.command_inout('Kill')
             self.join(self.timeout)
         finally:
-            os.unlink(self.db)
+            self.delete_db()
 
     def join(self, timeout=None):
         self.thread.join(timeout)
@@ -482,8 +518,8 @@ class DeviceTestContext(MultiDeviceTestContext):
 
     def __init__(self, device, device_cls=None, server_name=None,
                  instance_name=None, device_name=None, properties=None,
-                 db=None, host=None, port=0, debug=3,
-                 process=False, daemon=False, timeout=None):
+                 db=None, host=None, port=0, debug=3, process=False,
+                 daemon=False, timeout=None, memorized=None):
         # Argument
         if not server_name:
             server_name = device.__name__
@@ -493,6 +529,8 @@ class DeviceTestContext(MultiDeviceTestContext):
             device_name = 'test/nodb/' + server_name.lower()
         if properties is None:
             properties = {}
+        if memorized is None:
+            memorized = {}
         if device_cls:
             cls = (device_cls, device)
         else:
@@ -503,7 +541,8 @@ class DeviceTestContext(MultiDeviceTestContext):
                 "devices": (
                     {
                         "name": device_name,
-                        "properties": properties},
+                        "properties": properties,
+                        "memorized": memorized},
                 )
             },
         )
